Random Forest Classification
===========================================

.. raw:: html

    <script src="https://gist.github.com/semiautomaticgit/5b3c6dca89b3764a69cf083cf3d0674f.js"></script>

Link to the guide:
https://colab.research.google.com/gist/semiautomaticgit/5b3c6dca89b3764a69cf083cf3d0674f/random_forest_classification.ipynb
